reverse.pwave: Reverse wavelet transform a set of probabilities in TItable...

reverse.pwaveR Documentation

Reverse wavelet transform a set of probabilities in TItable format for Poisson data.

Description

Reverse wavelet transform a set of probabilities in TItable format for Poisson data.

Usage

reverse.pwave(est, lp, lq = NULL)

Arguments

est

An n-vector. Usually a constant vector with each element equal to the estimated log(total rate).

lp

A J by n matrix of probabilities.

lq

A J by n matrix of complementary probabilities.

Value

Reconstructed signal in the original data space.


smashr documentation built on Dec. 16, 2025, 1:07 a.m.