- x
A vector of observations. Reflection is done automatically
if length of x is not a power of 2.
- sigma
A vector of standard deviations. Can be provided if
known or estimated beforehand.
- v.est
Boolean indicating if variance estimation should be
performed instead.
- joint
Boolean indicating if results of mean and variance
estimation should be returned together.
- v.basis
Boolean indicating if the same wavelet basis should
be used for variance estimation as mean estimation. If false,
defaults to Haar basis for variance estimation (this is much faster
than other bases).
- post.var
Boolean indicating if the posterior variance should
be returned for the mean and/or variance estiamtes.
- filter.number
Choice of wavelet basis to be used, as in
wavethresh.
- family
Choice of wavelet basis to be used, as in
wavethresh.
- return.loglr
Boolean indicating if a logLR should be returned.
- jash
Indicates if the prior from method JASH should be
used. This will often provide slightly better variance estimates
(especially for nonsmooth variance functions), at the cost of
computational efficiency. Defaults to FALSE.
- SGD
Boolean indicating if stochastic gradient descent should
be used in the EM. Only applicable if jash=TRUE.
- weight
Optional parameter used in estimating overall
variance. Only works for Haar basis. Defaults to 0.5. Setting this
to 1 might improve variance estimation slightly.
- min.var
The minimum positive value to be set if the
variance estimates are non-positive.
- ashparam
A list of parameters to be passed to ash;
default values are set by function setAshParam.gaus.
- homoskedastic
indicates whether to assume constant variance
(if v.est is true)
- reflect
A logical indicating if the signals should be
reflected.