Learn R Programming

smashr (version 1.3-12)

treas: Three-month treasury bill data.

Description

Yields of the three-month Treasury Bill from the secondary market rates, on Fridays. The secondary market rates are annualised using a 360-day year of bank interest and are quoted on a discount basis. The data consist of 1735 weekly observations, from 5 January 1962 to 31 March 1995.

Usage

data(treas)

Arguments

Format

Data are stored in numeric (floating-point) vector, treas, with 1735 entries.

References

J. Fan and Q. Yao (1998). Efficient estimation of conditional variance functions in stochastic regression. Biometrika 85, 645--660.

Examples

Run this code
  # See smashr vignette.

Run the code above in your browser using DataLab